@@ -9,7 +9,7 @@ import sys
 import weakref
 
 from pathlib import Path
-from typing import List, Type
+from typing import List, Type, Optional
 
 import moderngl
 from moderngl_window.context.base import WindowConfig, BaseWindow
@@ -18,7 +18,7 @@ from moderngl_window.conf import settings
 from moderngl_window.utils.module_loading import import_string
 from moderngl_window.utils.keymaps import KeyMapFactory, KeyMap, QWERTY, AZERTY  # noqa
 
-__version__ = "2.4.4"
+__version__ = "2.4.6"
 
 IGNORE_DIRS = [
     "__pycache__",
@@ -60,9 +60,8 @@ def setup_basic_logging(level: int):
 
 class ContextRefs:
     """Namespace for window/context references"""
-
-    WINDOW = None
-    CONTEXT = None
+    WINDOW: Optional[BaseWindow] = None
+    CONTEXT: Optional[moderngl.Context] = None
 
 
 def activate_context(window: BaseWindow = None, ctx: moderngl.Context = None):
@@ -199,6 +198,7 @@ def run_window_config(config_cls: WindowConfig, timer=None, args=None) -> None:
         resizable=values.resizable
         if values.resizable is not None
         else config_cls.resizable,
+        visible=config_cls.visible,
         gl_version=config_cls.gl_version,
         aspect_ratio=config_cls.aspect_ratio,
         vsync=values.vsync if values.vsync is not None else config_cls.vsync,
@@ -272,6 +272,13 @@ def create_parser():
         default=None,
         help="Enable/disable window resize",
     )
+    parser.add_argument(
+        "-hd",
+        "--hidden",
+        type=valid_bool,
+        default=False,
+        help="Start the window in hidden mode",
+    )
     parser.add_argument(
         "-s",
         "--samples",
